@@ -3,9 +3,8 @@
 
 from .version  import __version__, VERSION
 from .monitor  import intercept, Context
-from .files    import Loader
 from .handler  import Handler, DefaultHandler, NPHandler
-from .args     import ArgsHandler
+from .args     import ArgsHandler, Args
 from .counter  import Counter
 from .registry import Registry
 from .db       import DB, new, save, load
